[Python-modules-commits] [python-pip] 02/08: Prevent pip from removing system packages.

Barry Warsaw barry at moszumanska.debian.org
Thu Feb 25 22:09:48 UTC 2016


This is an automated email from the git hooks/post-receive script.

barry pushed a commit to branch master
in repository python-pip.

commit 11a461c84e7ffa61865bfa0c9270c02bab12e41c
Author: Geoffrey Thomas <geofft at ldpreload.com>
Date:   Wed Dec 3 11:18:11 2014 -0600

    Prevent pip from removing system packages.
    
    Adjust is_local() to consider OS-owned paths non-local.  Fix the error
    message for is_local() in the non-virtualenv case.
    
    Author: Geoffrey Thomas <geofft at ldpreload.com>
    Bug-Debian: http://bugs.debian.org/771794
    Origin: https://github.com/geofft/pip.git
    Forwarded: not-needed
    Reviewed-By: Donald Stufft <donald at stufft.io>
    Reviewed-By: Scott Kitterman <scott at kitterman.com>
    Last-Update: 2014-12-04
    
    Patch-Name: hands-off-system-packages.patch
---
 pip/utils/__init__.py | 36 +++++++++++++++++++++++++++---------
 1 file changed, 27 insertions(+), 9 deletions(-)

diff --git a/pip/utils/__init__.py b/pip/utils/__init__.py
index 368d539..6489ea8 100644
--- a/pip/utils/__init__.py
+++ b/pip/utils/__init__.py
@@ -275,22 +275,40 @@ def renames(old, new):
 
 def is_local(path):
     """
-    Return True if path is within sys.prefix, if we're running in a virtualenv.
+    Return True if this is a path pip is allowed to modify.
 
-    If we're not in a virtualenv, all paths are considered "local."
+    If we're in a virtualenv, sys.prefix points to the virtualenv's
+    prefix; only sys.prefix is considered local.
+
+    If we're not in a virtualenv, in general we can modify anything.
+    However, if the OS vendor has configured distutils to install
+    somewhere other than sys.prefix (which could be a subdirectory of
+    sys.prefix, e.g. /usr/local), we consider sys.prefix itself nonlocal
+    and the domain of the OS vendor. (In other words, everything _other
+    than_ sys.prefix is considered local.)
 
     """
-    if not running_under_virtualenv():
-        return True
-    return normalize_path(path).startswith(normalize_path(sys.prefix))
+
+    path = normalize_path(path)
+    prefix = normalize_path(sys.prefix)
+
+    if running_under_virtualenv():
+        return path.startswith(normalize_path(sys.prefix))
+    else:
+        from pip.locations import distutils_scheme
+        if path.startswith(prefix):
+            for local_path in distutils_scheme("").values():
+                if path.startswith(normalize_path(local_path)):
+                    return True
+            return False
+        else:
+            return True
 
 
 def dist_is_local(dist):
     """
-    Return True if given Distribution object is installed locally
-    (i.e. within current virtualenv).
-
-    Always True if we're not in a virtualenv.
+    Return True if given Distribution object is installed somewhere pip
+    is allowed to modify.
 
     """
     return is_local(dist_location(dist))

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/python-modules/packages/python-pip.git



More information about the Python-modules-commits mailing list